<?
/* (c) 2000 Marco Pratesi (pratesi@telug.it) */

include("application.inc.php");

$SESSION["lang"] = "us";

$REFERER = get_referer();
$REFERER_AND_QUERY = get_full_referer();
if (!strpos($REFERER_AND_QUERY, "from_menu=yes")) {
	if ($REFERER == $REFERER_AND_QUERY) {
		$REFERER_AND_QUERY = $REFERER . "?from_menu=yes";
	} else {
		$REFERER_AND_QUERY = $REFERER_AND_QUERY . "&from_menu=yes";
	}
}
if ($SESSION["frames_used"]) { ?>
<script language="JavaScript">
<!--
parent.categories.location.reload();
parent.bodyframe.location.href="<?=$REFERER_AND_QUERY?>";
// -->
</script>
<?
} else {
header("Location: $REFERER_AND_QUERY");
}
?>
